
{*******************************************************}
{                                                       }
{     Borland Delphi Run-time Library                   }
{     Autodesk Animator external API Interface Unit     }
{                                                       }
{     Copyright (c) 1990-1992, Autodesk Corporation     }
{                                                       }
{     Translator: Sergey S. Tkachenko                   }
{     e-mail: tkachenko@360.com.ua                      }
{     Web:    www.4thfebruary.f2s.com                   }
{                                                       }
{*******************************************************}

unit aaPlay16;

{ AAPLAY.DLL is a dynamic link library which will
  play Autodesk Animator animation files and Windows
  device independent bitmap files.

  Using AAPLAY.DLL, applications can load, play and
  control animations under windows. AAPLAY can use
  Autodesk Animator Files, or Windows Device
  Independent Bitmap Files. AAPLAY.DLL can play an
  animation inside of a window, or it will take over
  the entire screen for animation playing.

  The C language header file aaplay.h makes all of the
  declarations needed for using the AA Play Library. }

{ Supported formats: .FLI  .FLC  .BMP  .DIB  .RLE  .AAS }

interface

uses WinTypes, WinProcs, SysUtils, Controls;

type
{ aaLoad return type }
  HandleAA = THandle;

const
  AA_BADPLAY = 1; {An error occurred reading the animation.}
  AA_BADNOTIFY = 2; {A memory error occurred attempting a frame synchronization message.}
  AA_BADSCRIPT = 3; {An error occurred loading an animation or sound for a script.}

{ aaGetCaps aType flags }
  AA_CAP_TIMER = 1;
  AA_CAP_SOUND = 2;
  AA_CAP_SCRIPT = 3;

  AA_STOP = 'AAPLAY Stop';
  AA_NOTIFY = 'AAPLAY Notify';

{ aaLoad wMode falgs }
  AA_MEMORYLOAD = 1;
  AA_HIDEWINDOW = 2;
  AA_NOPALETTE = 4;
  AA_RESERVEPALETTE = 8;
  AA_LOOPFRAME = 16;
  AA_FULLSCREEN = 32;
  AA_STOPNOTIFY = 64;
  AA_STOPSTATUS = 128;
  AA_NOFAIL = 256;
  AA_BUILDSCRIPT = 1024;

{ aaReLoad wMode additional flag }
  AA_DONTPAINT = 512;

{ aaGetParm wType flags }
  AA_STATUS = 1;
  { return values for aaGetParm  AA_STATUS }
    AA_STOPPED = 1;
    AA_QUEUED = 2;
    AA_PLAYING = 3;
    AA_PAUSED = 4;
    AA_DONE = 5;

  AA_FILETYPE = 2;
    AA_FLI = 1;
    AA_DIB = 2;
    AA_SCRIPT = 3;

  AA_MODE = 3;   {Returns a word containing the current mode of the
                  animation. The values are the same as the mode described
                  in aaLoad, except AA_NOFAIL and AA_BUILDSCRIPT are never
                  set.}
  AA_WINDOW = 4; {Returns a word containing the handle of the window that
                  owns the animation.}
  AA_SPEED = 5;  {Returns a word containing the speed of the animation,
                  given in milliseconds per frame. This is the current
                  speed of the animation.}
  AA_DESIGNSPEED = 6; {Returns a word containing the designed speed of the animation, given in milliseconds per frame}
  AA_FRAMES = 7; { Returns a word containing the number of frames in the animation. If the animation type is a DIB file,
                   this number will be unknown, until the animation has been completely played. If the number of frames is
                   unknown, 0 is returned.}
  AA_POSITION = 8; {Returns a long containing the current position in the animation. The high order word is the current loop,
                   the low order word is the current frame. The first loop is loop 0, and the first frame is frame 0.}
  AA_LOOPS = 9; {Returns a long returning the position of the frame at which the animation ends. A 0 indicates that the
                 animation will not stop until an aaStop call is made. This number has the same format as AA_POSITION.}
  AA_X = 10; {Returns the x coordinate of the upper left corner
              of the animation window.}
  AA_Y = 11; {Returns the y coordinate of the upper left corner
              of the animation window.}
  AA_CX = 12; {Returns the width of the animation window.}
  AA_CY = 13; {Returns the height of the animation window.}
  AA_ORGX = 14; {Returns the x coordinate in the animation, displayed
                 at the upper left corner of the animation window.}
  AA_ORGY = 15; {Returns the y coordinate in the animation, displayed
                 at the upper left corner of the animation window.}
  AA_WIDTH = 16; {Returns the width of the animation.}
  AA_HEIGHT = 17; {Returns the height of the animation.}
  AA_RPTSOUND = 18; {Returns the number of times the sound will repeat before stopping. Zero indicates that the sound
                     will repeat until the animation ends.}
  AA_PAUSE = 19; {Returns the length of time to pause this animation at the end in milliseconds.}
  AA_DELAYSND = 20; {Returns length of time to delay the sound from the start of the animation in milliseconds.
                     The delay is negative if the sound is to start before the animation.}
const
  AA_TRANSIN = 21; {Returns the transition at the beginning of the animation. This transition may be:}
    AA_CUT = 0; {No transition is performed.}
    AA_FADEBLACK = 1; {Fade from black transition is performed.}
    AA_FADEWHITE = 2; {Fade from white transition is performed.}

const
  AA_TRANSOUT = 22; {Returns the transition at the end of the animation. The transition may be:}
    {AA_CUT = 0;} {No transition is performed.}
    {AA_FADEBLACK = 1;} {Fade to black transition is performed. }
    {AA_FADEWHITE = 2;} {Fade to white transition is performed.}

  AA_TIMEIN = 23; {Returns the duration of the transition at the beginning of the animation in milliseconds. This
                    duration may be from .250 seconds to 10.000 seconds.}
  AA_TIMEOUT = 24; {Returns the duration of the transition at the end of the animation in milliseconds. This
                    duration may be from .250 seconds to 10.00 seconds.}
  AA_CALLBACK = 25; {Returns the handle of the window used to receive the status and notification messages.}
  AA_ANIMWND = 26; {Returns the handle of the window that actually contains the animation.}
  AA_FSDELAY = 28; {Returns the current delay used when switching modes for playing full screen 320 by 200
                     animations. This value is in milliseconds.}
  AA_MODFLAG = 100; {Returns the modified flag for the script. Zero means the script is not modified and a non-zero
                     value means the script is modified.}
  AA_SCRIPTNAME = 101; {Returns a global memory handle containing the name of the script. If the script is untitled,
                        or the animation is not a script, zero is returned.}
  AA_ANIMATION = 102; {Returns the number of the currently visible animation in a script. Zero is the first animation of
                       a script, or returned if the animation is not a script.}
  AA_ANIMATIONCOUNT = 103; {Returns the number of animations in a script. One is returned if the animation is not a script.}
  AA_SCRIPTCONTENTS = 104; {Returns a global memory handle containing the contents of the script. This handle contains the
                            script as it would appear in a text file, and is terminated by a null character. If the script is
                            empty, or the animation is not a script, zero is returned.}

  AA_LASTERROR = 1001; {Return the code for the last error detected by the player. This type should be used immediately after
                        detecting an error to determine the error. If the animation handle is zero, the player will search for
                        the last error for the calling application. If the animation handle is a valid handle, the player
                        searches for the last error for the application owning the animation. The error codes are:}
    AA_ERR_NOERROR = 0; {No error was detected.}
    AA_ERR_NOMEMORY = 256; {An out of memory condition was detected.}
    AA_ERR_BADHANDLE = 257; {The handle used in the last call to the player was invalid.}
    AA_ERR_NOTIMERS = 258; {A system timer could not be allocated for the animation.}
    AA_ERR_BADSOUND = 259; {The sound could not be opened.}
    AA_ERR_NOSCRIPT = 260; {The operation in error requires a script.}
    AA_ERR_WRITEERR = 261; {An error occured while saving the script.}
    AA_ERR_BADANIMATION = 262; {The animation could no be opened.}
    AA_ERR_BADWINDOWHANDLE = 512; {An invalid window handle was given to the player.}
    AA_ERR_WINDOWCREATE = 513; {An error occured when creating the animation window.}
    AA_ERR_DLGERROR = 514; {An unexpected error occured while processing a dialog box.}
    AA_ERR_INVALIDSTATUS = 768; {The function failed because the state of the animation did not allow it.}
    AA_ERR_BADDIBFORMAT = 769; {The Windows DIB file is corrupted.}
    AA_ERR_BADFLIFORMAT = 770; {The Autodesk Animator or Animator Pro file is corrupted.}
    AA_ERR_UNRECOGNIZEDFORMAT = 771; {The file is in an unrecognized format.}
    AA_ERR_NOSOUND = 772; {Sound is not supported by the player.}
    AA_ERR_NOTVALIDFORSCRIPTS = 773; {The request is not allowed for scripts, only for animations.}
    AA_ERR_INVALIDFILE = 774; {The file handle for the animation is invalid.}
    AA_ERR_NOSCRIPTS = 775; {Scripts are not supported by the player.}
    AA_ERR_SPEED = 1024; {The speed is invalid. The speed must be from 19 to 1000 milliseconds.}
    AA_ERR_LOOPS = 1025; {The loops are invalid. The number of loops may range from 0 to 999.}
    AA_ERR_RPTSOUND = 1026; {The number of sound repetitions are invalid.
                             This value may range from 0 to 1000.}
    AA_ERR_PAUSE = 1027; {The time to pause at the end of the animation is invalid.
                          This value may range from 0 to 50000 milliseconds.}
    AA_ERR_TRANSIN = 1028; {The starting transition is invalid. Transitions must
                            be one of the codes described above.}
    AA_ERR_TIMEIN = 1029; {The duration of the starting transition is invalid.
                            It ranges from 250 to 10000 milliseconds.}
    AA_ERR_TRANSOUT = 1030; {The ending transition is invalid.
                             It must be one of the codes described above.}
    AA_ERR_TIMEOUT = 1031; {The time of the ending transition is invalid.
                             It may rang from 250 to 10000 milliseconds.}
    AA_ERR_DELAYSND = 1032; {The delay of the sound from the start of the animation is invalid.
                             It may range from -3000000 to 3000000 milliseconds.}
    AA_ERR_INVALIDTYPE = 1033; {The type parameter to aaGetParm, aaSetParm or aaSetParmIndirect is invalid.}
    AA_ERR_DUPLICATENOTIFY = 1280; {An attempt was made to add a duplicate notification.}
    AA_ERR_NOSWITCH = 1536; {A script line is missing an option switch, or the switch is invalid.}
    AA_ERR_PARSELOOPS = 1537; {The number of loops on a script line is invalid.}
    AA_ERR_PARSESPEED = 1538; {The speed on a script line is invalid.}
    AA_ERR_BADRPTSOUND = 1540; {The number of sound repetitions on a script line is invalid.}
    AA_ERR_PARSEPAUSE = 1541; {The pause at the end of an animation on a script line is invalid.}
    AA_ERR_PARSETRANS = 1542; {A transition value is invalid.}
    AA_ERR_PARSEDELAYSND = 1543; {The delay of a sound from the beginning of the animation is invalid.}

  AA_LASTERRORMESSAGE = 1002; {A handle to a string containing text for the error
                               code retrieved by AA_LASTERROR is returned.
                               This string may be displayed in a message box.
                               If the error is in a script, and the animation name
                               of the line which caused the error is known, the name
                               of the animation will be in the message. The player
                               will also copy the message into a buffer, if aaSetParm
                               is used.}
  AA_FRAMEBITMAP = 2000; {A handle to a Device Independent Bitmap for the current
                          frame is returned. The frame does not need to be visible
                          in order to return the bitmap.}

function aaOpen: Boolean;
function aaGetCaps(aType: Word): Word;
procedure aaClose;
function aaLoad(lpzFileName: PChar; hWnd: HWND; wMode: Word; X, Y, cX, cY, orgX, orgY: Word): HandleAA;
function aaUnLoad(hAa: HandleAA): Boolean;
function aaReLoad(hAa: HandleAA; lpzFileName: PChar; wMode: Word; wMask: Word): Boolean;
function aaPlay(hAa: HandleAA): Boolean;
function aaPause(hAa: HandleAA): Boolean;
function aaStop(hAa: HandleAA): Boolean;
function aaNotify(hAa: HandleAA; lPosition: LongInt; lParam: LongInt): Boolean;
function aaCancel(hAa: HandleAA; lLowPos: LongInt; lHighPos: LongInt): Word;
function aaPrompt(hAa: HandleAA; lpName: PChar): Boolean;
function aaGetParm(hAa: HandleAA; wType: Word): LongInt;

type
  LONG = LongInt;
  AASPEED = LongInt;

  PAAPARMS = ^AAPARMS;
  AAPARMS = record
    aa_status: Byte;
    aa_filetype: Byte;
    aa_mode: Byte;
    aa_bitpix: Byte;
    aa_hwnd: HWND;
    aa_x, aa_y, aa_cx, aa_cy: Integer;
    aa_orgx, aa_orgy: Integer;
    aa_speed: AASPEED;
    aa_designspeed: AASPEED;
    aa_frames: Word;
    aa_position: LongInt;
    aa_loops: LongInt;
    aa_rptsound: Word;
    aa_pause: Word;
    aa_delaysnd: LONG;
    aa_transin: Byte;
    aa_transout: Byte;
    aa_timein: Word;
    aa_timeout: Word;
    aa_callback: Word;
    aa_animwnd: Word;
    aa_fsdelay: Word;
  end;

function aaGetParmIndirect(hAa: HandleAA; lpAparm: PAAPARMS; wSize: Word): Boolean;
function aaSetParm(hAa: HandleAA; wType: Word; wValue1: Word; lValue2: LongInt): HandleAA;
function aaSetParmIndirect(hAa: HandleAA; dwType: LongInt; lpAparm: PAAPARMS; wMask: Word): HandleAA;

const
{ aaSetParamIndirect dwType flags }
  AA_SETMODE = 1;
  AA_SETWINDOW = 2;
  AA_SETSPEED = 4;
  AA_SETPOSITION = 8;
  AA_SETLOOPS = 16;
  AA_SETX = 32;
  AA_SETY = 64;
  AA_SETCX = 128;
  AA_SETCY = 256;
  AA_SETORGX = 512;
  AA_SETORGY = 1024;
  AA_SETRPTSOUND = 2048;
  AA_SETPAUSE = 4096;
  AA_SETDELAYSND = 8192;
  AA_SETTRANSIN = 16384;
  AA_SETTRANSOUT = 32768;
  AA_SETTIMEIN = 65536;
  AA_SETTIMEOUT = 131072;
  AA_SETCALLBACK = 262144;

function aaShow(hAa: HandleAA; bShow: Boolean): Boolean;
function aaSound(hAa: HandleAA; lpszDevice: PChar; lpszSound: PChar; wMode: Word): Boolean;

const
  { aaSound wMode flags }
  AA_SNDFREEZE = 1; {Normally the animation continues to play when the sound
                     is being prepared for playing. Setting this value prevents
                     this from happening.}
  AA_SNDDEVICEID = 256; {Indicates that the device value is not the name of
                         a sound device, but is the MultiMedia Control Interface
                         Type ID.}

function aaGetFile(wFlags: Word; lpzFileName: PChar; wSizeFile: Word; lpzDeviceName: PChar; wSizeDevice: Word): Integer;

const
{ aaGetFile wFlags flags }
  AA_GETFILE_MUSTEXIST = 1; {If set the file entered must exist before aaGetFile
                             will return.}
  AA_GETFILE_NOSHOWSPEC = 2; {If set the search specification is not displayed
                              in the file name edit control.}
  AA_GETFILE_SAVE = 4; {If set the OK button is changed to read "Save", and the
                        caption reads "Save". Setting this value automatically
                        sets the AA_GETFILE_USEFILE flag.}
  AA_GETFILE_OPEN = 8; {If set the OK button is changed to read "Open", and the
                        caption reads "Open"}
  AA_GETFILE_USEDIR = 16; {If set the directory of the current contents of the
                           string addressed by lpzFileName is used as the initial
                           directory in the dialog.}
  AA_GETFILE_USEFILE = 32; {If set the file name of the current contents of the
                            string addressed by lpzFileName is put in the file
                            name edit control.}
  AA_GETFILE_SOUND = 64; {If set the file specification for sound files is used
                          in the dialog, and the caption reads "Sound". If none
                          of AA_GETFILE_SCRIPT, AA_GETFILE_ANIMATION and
                          AA_GETFILE_SOUND are set in wFlags, the file specification
                          for animation and script files is used in the dialog, and
                          the caption reads "Sound".}
  AA_GETFILE_SCRIPT = 128; {If set the file specification for script files is used
                            in the dialog, and the caption reads "Script". If none
                            of AA_GETFILE_SCRIPT, AA_GETFILE_ANIMATION and
                            AA_GETFILE_SOUND are set in wFlags, the file specification
                            for animation and script files is used in the dialog, and
                            the caption reads "Script".}
  AA_GETFILE_ANIMATION = 256; {If set the file specification for animation files is
                               used in the diloag and the caption reads "Animation".
                               If none of AA_GETFILE_SCRIPT, AA_GETFILE_ANIMATION
                               and AA_GETFILE_SOUND are set in wFlags, the file
                               specification for animation and script files is used
                               in the dialog, and the caption reads "Animation".}

function aaSave(hAa: HandleAA; wMode: Word): Integer;

function aaPLoad(FileName: string; Control: TWinControl; FullScreen: Boolean): THandle;

const
{  aaSave wMode flags }
  AA_SAVE_IFMODIFIED = 1; {The script is only saved if it has been modified.}
  AA_SAVE_AS = 2; {The user is prompted for a new file name to save the script. If the script is untitled,
                   the used is always prompted for a file name, whether or not this flag is set.}
  AA_SAVE_CANCEL = 4; {When saving a modified file, a Cancel button is added to the Save File Alert.}

implementation

const
  aa16 = 'aaplay.dll';

function aaOpen; external aa16 name 'aaOpen';
function aaGetCaps; external aa16 name 'aaPlay';
procedure aaClose; external aa16 name 'aaClose';
function aaLoad; external aa16 name 'aaLoad';
function aaUnLoad; external aa16 name 'aaUnload';
function aaReLoad; external aa16 name 'aaReLoad';
function aaPlay; external aa16 name 'aaPlay';
function aaPause; external aa16 name 'aaPause';
function aaStop; external aa16 name 'aaStop';
function aaNotify; external aa16 name 'aaNotify';
function aaCancel; external aa16 name 'aaCancel';
function aaPrompt; external aa16 name 'aaPromt';
function aaGetParm; external aa16 name 'aaGetParm';
function aaGetParmIndirect; external aa16 name 'aaGetParmIndirect';
function aaSetParm; external aa16 name 'aaSetParm';
function aaSetParmIndirect; external aa16 name 'aaSetParmIndirect';
function aaShow; external aa16 name 'aaShow';
function aaSound; external aa16 name 'aaSound';
function aaGetFile; external aa16 name 'aaGetFile';
function aaSave; external aa16 name 'aaSave';

function aaPLoad(FileName: string; Control: TWinControl; FullScreen: Boolean): THandle;
var
  P: array[0..255] of Char;
  H: Word;
begin
  StrPCopy(P, FileName);
  if FullScreen then
    H := aaLoad(P, Control.Handle, 32, 0, 0, 0, 0, 0, 0)
  else
    H := aaLoad(P, Control.Handle, 0, 0, 0, 0, 0, 0, 0);
  aaPause(H);
  Result := H;
end;

end.
