
{*******************************************************}
{                                                       }
{     Borland Delphi Visual Component Library           }
{     FLIC Player Component Unit                        }
{                                                       }
{     Copyright (c) 1996-2001, Sergey S. Tkachenko      }
{                                                       }
{     e-mail: tkachenko@360.com.ua                      }
{     Web:    www.4thfebruary.f2s.com                   }
{                                                       }
{*******************************************************}

unit FlicComp;

{$X+}

interface

uses SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, ExtCtrls, MMSystem;

type
  EFlicPlayer = class(Exception);

  TPlayerStatus = (apsStopped, apsQueued, apsPlaying, apsPaused, apsDone);

  TFileType = (aftUnknown, aftFLI, aftDIB, aftScript);

  TFlicPlayer = class(TCustomPanel)
  private
    FAutoPlay: Boolean; {Bei True wird FLI gestartet}
    FAutoSize: Boolean;
    AAHandle: Integer;
    FFileName: string;  {Name der FLI-Datei}
    FFileType: TFileType;
    FFrames: LongInt; {Anzahl der Einzelbilder}
    FFullScreen: Boolean;
    FPlayerStatus: TPlayerStatus;
    FSoundFile: string;
    FStatus: TPlayerStatus;

    procedure SetAutoSize(Value: Boolean);
    procedure SetFileName(AFileName: string);
    procedure SetAutoPlay(AAutoPlay: Boolean);
    procedure SetPosition(APosition: LongInt);
    function GetPosition: LongInt;
    procedure SetSoundFile(Value: string);
    procedure SetFullScreen(Value: Boolean);
  protected
{    constructor Create(AOwner: TComponent); override;}
{    destructor Destroy; override;}
  public
    property Canvas;
    property FileType: TFileType read FFileType;
    property Status: TPlayerStatus read FPlayerStatus;

    procedure Play;
    procedure Stop;
    procedure Pause;
    procedure Next;
    procedure Previous;
  published
    property AutoPlay: Boolean read FAutoPlay write SetAutoPlay default False;
    property AutoSize: Boolean read FAutoSize write SetAutoSize default True;
    property Frames: LongInt read FFrames;
    property FileName: string read FFileName write SetFileName;
    property FullScreen: Boolean read FFullScreen write SetFullScreen default False;
    property Position: LongInt read GetPosition write SetPosition;
    property SoundFile: string read FSoundFile write SetSoundFile;
    { TCustomPanel standard properties}
    property Align;
    property BevelInner;
    property BevelOuter;
    property BevelWidth;
    property BorderStyle;
    property BorderWidth;
    property Color;
    property Enabled;
    property Height;
    property Hint;
    property HelpContext;
    property ParentColor;
    property ParentShowHint;
    property ShowHint;
    property Visible;
    property Width;
    property Tag;
    property TabStop;

    property OnClick;
    property OnDblClick;
    property OnDragDrop;
    property OnDragOver;
    property OnEndDrag;
    property OnMouseDown;
    property OnMouseMove;
    property OnMouseUp;
    property OnResize;
{    property OnPlay: TNotifyEvent;}
{    property OnDone: TNotifyEvent;}
{    property OnPause: TNotifyEvent;}
{    property OnStop: TNotifyEvent;}
  end;

procedure Register;

implementation

uses aaPlay16;

procedure TFlicPlayer.SetAutoPlay(AAutoPlay: Boolean);
begin
  FAutoPlay := AAutoPlay;
  if AAutoPlay then AAPlay(AAHandle) else AAStop(AAHandle);
end;

procedure TFlicPlayer.SetFullScreen(Value: Boolean);
begin
  if (FFullScreen <> Value) then
  begin
    FFullScreen := Value;
    aaUnLoad(AAHandle);
  end;
  SetFileName(FFileName);
end;

procedure TFlicPlayer.SetAutoSize(Value: Boolean);
begin
  if (FAutoSize <> Value) then
    FAutoSize := Value;
end;

procedure TFlicPlayer.SetFileName(AFileName: string);
const
  FirstTime: Boolean = True;
var
  Rand: Integer;
  ftli: LongInt;
  sf: string;
begin
  if FirstTime then AAOpen;
  FirstTime := False;
  Rand := BorderWidth;

  if BevelInner <> bvNone then Rand := Rand + BevelWidth;
  if BevelOuter <> bvNone then Rand := Rand + BevelWidth;

  aaUnLoad(AAHandle);

  if FileExists(AFileName) then
  begin
    FFileName := ExpandFileName(AFileName);
    if (not FFullScreen) then
      AAHandle := aaPLoad(AFileName, Self, False)
    else
      AAHandle := aaPLoad(AFileName, Self, True);
    aaSetParm(AAHandle, AA_X, Rand, 0);
    aaSetParm(AAHandle, AA_Y, Rand, 0);
    Width := aaGetParm(AAHandle, AA_WIDTH) + 2 * Rand;
    Height := aaGetParm(AAHandle, AA_HEIGHT) + 2 * Rand;
    FFrames := aaGetParm(AAHandle, AA_FRAMES);
{    case aaGetParm(AAHandle, 2) of
      1: FileType := aftFLI;
      2: FileType := aftDIB;
      3: FileType := aftScript;
    else
      FileType := aftUnknown;
    end;}
    if FAutoPlay then aaPlay(AAHandle);
  end else
    FFileName := '';
end;

procedure TFlicPlayer.SetPosition(APosition: LongInt);
begin
  aaSetParm(AAHandle, AA_Position, 0, APosition);
end;

function TFlicPlayer.GetPosition: LongInt;
begin
  Result := aaGetParm(AAHandle, AA_POSITION);
end;

procedure TFlicPlayer.Play;
begin
  AAPlay(AAHandle);
end;

procedure TFlicPlayer.Stop;
begin
  AAStop(AAHandle);
end;

procedure TFlicPlayer.Pause;
begin
  AAPause(AAHandle);
end;

procedure TFlicPlayer.Next;
begin
  if Position < Frames - 1 then
    Position := Position + 1
  else
    Position := 0;
end;

procedure TFlicPlayer.Previous;
begin
  if Position > 0 then
    Position := Position - 1
  else
    Position := Frames - 1;
end;

procedure TFlicPlayer.SetSoundFile(Value: string);
var
  P: array[0..255] of Char;
  ret: Boolean;
begin
  if FSoundFile <> Value then
  begin
    FSoundFile := Value;
    StrPCopy(P, Value);
    ret := aaSound(aaHandle, 'waveaudio', P, AA_SNDFREEZE);
  end;
end;

procedure Register;
begin
  RegisterComponents('Samples', [TFlicPlayer]);
end;

end.
